#' do_fit

#' do_fit
#' @param service service
#' @param algorithm algorithm in character
#' @param ... other parame related to fitting the model
#' @param dataset tibble or data.frame
#' @param col_bind col_bind in character
#' @param target target in character
#' @param predictors predictors in character
#' @param train train percentage
#' @param test test percentage
#' @keywords algoli
#' @export
#' @examples
#' \dontrun{
#' do_fit()
#' }
do_fit <- function(service,algorithm=NULL,...,dataset,col_bind=NULL,target,predictors, train=0.8,test=0.2){

  id <- stringi::stri_rand_strings(1, 16,'[a-z0-9]')

  fileCheck_path <- normalizePath(file.path(tempdir(),"algoli"),mustWork = FALSE)
  fileCheck_path <- normalizePath(fileCheck_path,mustWork = FALSE)
  dir.create(fileCheck_path, showWarnings = TRUE, recursive = TRUE)
  fileCheck <- file.path(fileCheck_path,paste0('fit-check_',id,'_.log'))
  file.create(fileCheck)

  target <- gsub("\\.","_",target)
  predictors <- gsub("\\.","_",predictors)

  # new algoli
  hello <- algoli::algdoor(service = service)

  # Connecting to session ...
  cat(c(as.character(Sys.time()),"connecting\n"), file=fileCheck,append=TRUE)
  hello$connect()

  # Incoporating dataset into session  ...
  cat(c(as.character(Sys.time()),"copying and splitting dataset\n"), file=fileCheck,append=TRUE)
  hello$dataset(dataset=dataset,col_bind= col_bind, train=train,test=test)

  # Fitting the model on the training dataset ...
  cat(c(as.character(Sys.time()),"fit model on training\n"), file=fileCheck,append=TRUE)
  res_fit <- hello$fit(algorithm=algorithm,target=target,predictors=predictors,...)

  # exporting model ...
  cat(c(as.character(Sys.time()),"export model\n"), file=fileCheck,append=TRUE)
  tmp_model_path <- normalizePath(file.path(tempdir(),"algoli",id),mustWork = FALSE)
  dir.create(tmp_model_path, showWarnings = TRUE, recursive = TRUE)
  model_path <- hello$export_model(res_fit,tmp_model_path)

  # Prediction on the test dataset ...
  cat(c(as.character(Sys.time()),"predict\n"), file=fileCheck,append=TRUE)
  res_pred <- hello$predict(res_fit)

  res <- list(service = service,
              alg  = algorithm,
              args = list(...),
              target = target,
              predictors = predictors,
              col_bind = col_bind,
              pred = res_pred,
              id = id,
              path = model_path)

  # disconnect ...
  cat(c(as.character(Sys.time()),"disconnect\n"), file=fileCheck,append=TRUE)
  hello$disconnect()

  return(res)
}
