#' do_predict

#' do_predict
#' @param service service
#' @param model_path path to models
#' @param model_id  model id
#' @param dataset tibble or data.frame
#' @param col_bind col_bind in character
#' @keywords algoli
#' @export
#' @examples
#' \dontrun{
#' do_predict()
#' }
do_predict <- function(service,model_path,model_id,dataset=NULL,col_bind=NULL){

  fileCheck_path <- normalizePath(file.path(tempdir(),"algoli"),mustWork = FALSE)
  fileCheck_path <- normalizePath(fileCheck_path,mustWork = FALSE)
  dir.create(fileCheck_path, showWarnings = TRUE, recursive = TRUE)
  fileCheck <- file.path(fileCheck_path,paste0('predict-check_',model_id,'_.log'))
  file.create(fileCheck)

  # new algoli
  hello <- algoli::algdoor(service = service)

  # Connecting to session ...
  cat(c(as.character(Sys.time()),"connecting\n"), file=fileCheck,append=TRUE)
  hello$connect()

  # Incoporating dataset into session  ...
  cat(c(as.character(Sys.time()),"copying dataset\n"), file=fileCheck,append=TRUE)
  hello$dataset(dataset=dataset,col_bind= col_bind, train=0L,test=100L)

  # Loading the model ...
  cat(c(as.character(Sys.time()),"loading model\n"), file=fileCheck,append=TRUE)
  res_fit <- hello$load_model(file.path(model_path,model_id,"model.mod"))

  # Prediction on the dataset ...
  cat(c(as.character(Sys.time()),"predict\n"), file=fileCheck,append=TRUE)
  res_pred <- hello$predict(res_fit)

  res <- list(pred = res_pred,
              id = model_id,
              path = model_path)

  # disconnect ...
  cat(c(as.character(Sys.time()),"disconnect\n"), file=fileCheck,append=TRUE)
  hello$disconnect()

  return(res)
}
